==> ldimbenchmark-0.2.14-py3-none-any.whl: ldimbenchmark/methods/test_complexity_polynomial.py <==
import math
from time import sleep
from ldimbenchmark import LDIMMethodBase, BenchmarkData, BenchmarkLeakageResult
from ldimbenchmark.classes import MethodMetadata, MethodMetadataDataNeeded
from typing import List, Union


class TestPolynomialComplexityLeakageDetectionMethod(LDIMMethodBase):
    """
    Test Complexity: Polynomial
    """

    def __init__(self):
        super().__init__(
            name="Polynomial Complexity",
            version="1.0",
            metadata=MethodMetadata(
                data_needed=MethodMetadataDataNeeded(
                    pressures="ignored",
                    flows="ignored",
                    levels="ignored",
                    model="ignored",
                    demands="ignored",
                    structure="ignored",
                ),
                hyperparameters=[],
            )
            # hyperparameters={"est_length": "3 days", "C_threshold": 3, "delta": 4},
        )

    def prepare(self, train_data: BenchmarkData) -> None:
        sleep(
            (len(train_data.demands[list(train_data.demands.keys())[0]]) ** 2) / 10000
        )
        return

    def detect_offline(
        self, evaluation_data: BenchmarkData
    ) -> List[BenchmarkLeakageResult]:
        sleep(
            (len(evaluation_data.demands[list(evaluation_data.demands.keys())[0]]) ** 2)
            / 10000
        )
        return []

    def detect_online(self, evaluation_data) -> Union[BenchmarkLeakageResult, None]:
        return None

==> ldimbenchmark-0.2.15-py3-none-any.whl: ldimbenchmark/methods/test_complexity_polynomial.py <==
import math
from time import sleep
from ldimbenchmark import LDIMMethodBase, BenchmarkData, BenchmarkLeakageResult
from ldimbenchmark.classes import MethodMetadata, MethodMetadataDataNeeded
from typing import List, Union


class TestPolynomialComplexityLeakageDetectionMethod(LDIMMethodBase):
    """
    Test Complexity: Polynomial
    """

    def __init__(self):
        super().__init__(
            name="Polynomial Complexity",
            version="1.0",
            metadata=MethodMetadata(
                data_needed=MethodMetadataDataNeeded(
                    pressures="ignored",
                    flows="ignored",
                    levels="ignored",
                    model="ignored",
                    demands="ignored",
                    structure="ignored",
                ),
                hyperparameters=[],
            )
            # hyperparameters={"est_length": "3 days", "C_threshold": 3, "delta": 4},
        )

    def prepare(self, train_data: BenchmarkData) -> None:
        sleep(
            (len(train_data.demands[list(train_data.demands.keys())[0]]) / 280) ** 1.2) / 100
        )
        return

    def detect_offline(
        self, evaluation_data: BenchmarkData
    ) -> List[BenchmarkLeakageResult]:
        sleep(
            (
                (len(evaluation_data.demands[list(evaluation_data.demands.keys())[0]]) / 280)
                ** 1.2
            )
            / 100
        )
        return []

    def detect_online(self, evaluation_data) -> Union[BenchmarkLeakageResult, None]:
        return None
